This module generates a Content Insights Report that provides valuable data and analysis about the content in your system. The report is based on various parameters, including content type, status, and workflows, giving you insights into the overall performance and status of the content within your system.

<h3 id="module-project--features">Features</h3>
<h4>Content Insights Summary</h4>
<strong>Purpose: </strong>This section provides a high-level overview of content distribution based on content type.
<strong>Description:</strong>
<ul>
  <li>The report calculates and presents a percentage breakdown of content based on the total number of content nodes or based on the total number of published nodes.</li>
<li>For example, if you have multiple content types (e.g., Articles, Blog Posts, Product Pages), the summary will show what percentage of the total content belongs to each type.</li>
<li>This is particularly useful for understanding the content mix and evaluating the prevalence of different content types in your system.</li>
</ul>
<h4>Content Insights Report</h4>
<strong>Purpose: </strong>This section provides a deeper, more granular look into content creation, updates, and workflow status.
<strong>Description:</strong>
<ul>
  <li><strong>Percentage Breakdown:</strong> Similar to the Content Type Summary, this report provides a percentage-based view of content status, but it's based on the total number of nodes or published nodes. This allows you to compare different categories of content and track overall progress.</li>
<li><strong>Monthly Trends (Created/Updated Nodes):</strong>
The report tracks content activity over time, focusing on when nodes were created and updated. The data is broken down into months, with the number of new and updated nodes calculated and visualised for each month. The months displayed are configurable, allowing you to define the reporting period based on your needs (e.g., last 6 months, last year).
</li>
<li><strong>Workflow – Moderation State:</strong> This section provides insights into the current workflow status of content nodes, specifically focusing on the Moderation State. This includes data on whether the content is in draft, pending approval, published, or in other stages of the workflow. This can help identify bottlenecks, delays, or content that is stuck in a particular moderation stage.
</li>
</ul>
<h4>Why use Content Insights Report as the project name?</h4>
"Content Insights" refers to the valuable data, analysis, and actionable information derived from the performance, status, and engagement of digital content. These insights help content creators, marketers, and stakeholders understand how content is performing, how users are interacting with it, and how content aligns with business goals. The goal of content insights is to inform decisions related to content creation, distribution, optimization, and strategy.

<h3 id="module-project--post-installation">Post-Installation</h3>
<strong>Configuration:</strong> Navigate to Configuration > Content authoring > Content Insights Report using the Admin Toolbar.
Alternatively, you can also use this link: <em>/admin/config/content/content_insights_report/settings</em>
<strong>Report:</strong> Navigate to Reports > Content Insights Report using the Admin Toolbar.
Alternatively, you can also use this link: <em>/admin/reports/content-insights-report</em>

<h3 id="module-project--similar-projects">Similar projects</h3>
Although there are other reporting modules for Drupal, this one stands out because of its intuitive interface, wide range of configuration options, and emphasis on real-time data while maintaining strong performance.
<a href="https://www.drupal.org/project/content_type_audit">Content Type Audit</a>, <a href="https://www.drupal.org/project/content_type_report ">Content Type Report</a>, <a href="https://www.drupal.org/project/content_report ">Content Report</a>, <a href="https://www.drupal.org/project/content_reporting">Content Reporting</a>

<h3 id="module-project--support">Supporting this Module</h3>
If you need support or have feedback on Content Reporting module, you can <a href="https://www.drupal.org/node/add/project-issue/content_insights_report">submit a support request or report an issue here</a>.

<h3 id="module-project--roadmap">Roadmap</h3>
The module's roadmap involves resolving any issues raised in the project issue tracker and introducing a submodule for the Group module to present the same report for individual group.
