<?php

namespace Drupal\content_insights_report\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Content Insights Report settings for this site.
 */
class ContentInsightsReportConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'content_insights_report.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'content_insights_report_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('content_insights_report.settings');

    $form['reports'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Content Insights Reports'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    ];

    $form['reports']['report_content_insights_summary'] = [
      '#type' => 'fieldset',
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    ];
    // Show Summary of % field
    $form['reports']['report_content_insights_summary']['show_summary'] = [
      '#type' => 'select',
      '#title' => $this->t('Show Content Insights Summary Report'),
      '#options' => [
        'yes' => $this->t('Yes'),
        'no' => $this->t('No'),
      ],
      '#default_value' => $config->get('show_summary') ?: 'yes',
      '#description' => $this->t('Choose whether to display the Content Insights Summary Report.<br><b>Default:</b> Yes'),
    ];

    $form['reports']['report_content_insights'] = [
      '#type' => 'fieldset',
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    ];
    // Show Insights Report field
    $form['reports']['report_content_insights']['show_insights_report'] = [
      '#type' => 'select',
      '#title' => $this->t('Show Content Insights Report'),
      '#options' => [
        'yes' => $this->t('Yes'),
        'no' => $this->t('No'),
      ],
      '#default_value' => $config->get('show_insights_report') ?: 'yes',
      '#description' => $this->t('Choose whether to display the Content Type Report. Report is based on created and update dates of content.<br><b>Default:</b> Yes'),
    ];

    // Show Workflow Moderation State Report
    $moduleHandler = \Drupal::service('module_handler');
    $moderation_state_attributes = [];
    if (!$moduleHandler->moduleExists('content_moderation')) {
      $moderation_state_attributes['disabled'] = 'disabled';
    }
    $form['reports']['report_content_insights']['show_workflow_moderation_state_report'] = [
      '#attributes' => $moderation_state_attributes,
      '#type' => 'select',
      '#title' => $this->t('Show Workflow Moderation State Report'),
      '#options' => [
        'yes' => $this->t('Yes'),
        'no' => $this->t('No'),
      ],
      '#default_value' => $config->get('show_workflow_moderation_state_report') ?: 'yes',
      '#description' => $this->t('Choose whether to display the Workflow Moderation State Report.<br>If field is disabled: Install module Content Moderation (content_moderation).<br><b>Default:</b> No'),

    ];

    $form['configurations'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Content Insights Configurations'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    ];

    // Percentage total based on? field
    $form['configurations']['show_created_by_and_date'] = [
      '#type' => 'select',
      '#title' => $this->t('Show created by and date'),
      '#options' => [
        'yes' => $this->t('Yes'),
        'no' => $this->t('No'),
      ],
      '#default_value' => $config->get('show_created_by_and_date') ?: 'yes',
      '#description' => $this->t('Show created by and date of when the report was executed.<br><b>Format:</b> Create by username on 2024/09/19 05:36'),
    ];

    // Percentage total based on? field
    $form['configurations']['percentage_total'] = [
      '#type' => 'select',
      '#title' => $this->t('Total percentage based on?'),
      '#options' => [
        'all_nodes' => $this->t('All nodes'),
        'published_nodes' => $this->t('Published nodes'),
        'unpublished_nodes' => $this->t('Unpublished nodes'),
      ],
      '#default_value' => $config->get('percentage_total') ?: 'all_nodes',
      '#description' => $this->t('Select the percentage total based on.<br><b>All nodes:</b> include published and unpublished nodes.<br><b>Published nodes:</b> Published nodes.<br><b>Unpublished nodes:</b> Unpublished nodes.'),
    ];


    // Number of Months to show for created an dupdated activities field
    $form['configurations']['number_of_months'] = [
      '#type' => 'number',
      '#title' => $this->t('Number of Months to show in report.'),
      '#default_value' => $config->get('number_of_months') ?: 4,
      '#min' => 1,
      '#description' => $this->t('Select the number of months.<br>Minimum is 1.<br><b>Default:</b> 6'),
    ];

    // Sort Insights By field
    $form['configurations']['sort_by'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Sort Insights by'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    ];
    $form['configurations']['sort_by']['sort_by_field'] = [
      '#type' => 'select',
      '#title' => $this->t('Field'),
      '#options' => [
        'content_type' => $this->t('Content type (Name)'),
        'content_type_machine' => $this->t('Content type (Machine name)'),
        'total_percentage' => $this->t('Total %'),
      ],
      '#default_value' => $config->get('sort_by_field') ?: 'content_type',
      '#description' => $this->t('Select field for sorting criteria for the results.<br><b>Default:</b> Total %'),
    ];
    $form['configurations']['sort_by']['sort_by_direction'] = [
      '#type' => 'select',
      '#title' => $this->t('Direction'),
      '#options' => [
        'asc' => $this->t('Ascending'),
        'desc' => $this->t('Descending'),
      ],
      '#default_value' => $config->get('sort_by_direction') ?: 'desc',
      '#description' => $this->t('Select direction for sorting criteria for the results.<br><b>Default:</b> Descending'),
    ];

    // Sort Month By field
    $form['configurations']['month_sort_by_direction'] = [
      '#type' => 'select',
      '#title' => $this->t('Display month order'),
      '#options' => [
        'asc' => $this->t('Ascending'),
        'desc' => $this->t('Descending'),
      ],
      '#default_value' => $config->get('month_sort_by') ?: 'desc',
      '#description' => $this->t('Select Month display order.<br><b>Default:</b> Descending'),
    ];

    // Print icon
    $form['configurations']['show_print'] = [
      '#type' => 'select',
      '#title' => $this->t('Show print icon'),
      '#options' => [
        'yes' => $this->t('Yes'),
        'no' => $this->t('No'),
      ],
      '#default_value' => $config->get('show_print') ?: 'yes',
      '#description' => $this->t('Select this option to display the print icon and print the selected section of the report.<br><b>Default:</b> Yes'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('content_insights_report.settings')
      ->set('show_summary', $form_state->getValue('show_summary'))
      ->set('show_insights_report', $form_state->getValue('show_insights_report'))
      ->set('show_workflow_moderation_state_report', $form_state->getValue('show_workflow_moderation_state_report'))
      ->set('show_created_by_and_date', $form_state->getValue('show_created_by_and_date'))
      ->set('percentage_total', $form_state->getValue('percentage_total'))
      ->set('number_of_months', $form_state->getValue('number_of_months'))
      ->set('sort_by_field', $form_state->getValue('sort_by_field'))
      ->set('sort_by_direction', $form_state->getValue('sort_by_direction'))
      ->set('month_sort_by_direction', $form_state->getValue('month_sort_by_direction'))
      ->set('show_print', $form_state->getValue('show_print'))
      ->save();

    parent::submitForm($form, $form_state);
  }
}
